@@ -10,9 +10,11 @@ use VOMS::Lite::X509;
 use VOMS::Lite::RSAKey;
 
 require Exporter;
-use vars qw(@ISA @EXPORT @EXPORT_OK %EXPORT_TAGS);
+use vars qw($VERSION @ISA @EXPORT @EXPORT_OK %EXPORT_TAGS);
 @ISA = qw(Exporter);
 
+$VERSION = '0.14';
+
 sub Examine {
   return VOMS::Lite::X509::Examine(@_);
 }
