@@ -6,9 +6,11 @@ use Math::BigInt lib => 'GMP';
 use 5.004;
 use strict;
 require Exporter;
-use vars qw(@ISA @EXPORT @EXPORT_OK %EXPORT_TAGS);
+use vars qw($VERSION @ISA @EXPORT @EXPORT_OK %EXPORT_TAGS);
 @ISA = qw(Exporter);
 
+$VERSION = '0.14';
+
 my $DefaultRandom=undef;
 my ($CryptCtx,$Generator);
 my $urdev="/dev/urandom";
