@@ -15,8 +15,9 @@ use Digest::SHA1 qw(sha1_hex sha1);
 use Crypt::CBC;
 
 require Exporter;
-use vars qw($DEBUG @ISA @EXPORT @EXPORT_OK %EXPORT_TAGS);
+use vars qw($VERSION $DEBUG @ISA @EXPORT @EXPORT_OK %EXPORT_TAGS);
 @ISA = qw(Exporter);
+$VERSION = '0.14';
 
 BEGIN {
   $DEBUG='no';
